'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Collapsible = _react2.default.createClass({
  displayName: 'Collapsible',


  //Set validation for prop types
  propTypes: {
    transitionTime: _react2.default.PropTypes.number,
    triggerText: _react2.default.PropTypes.string.isRequired,
    easing: _react2.default.PropTypes.string,
    startOpen: _react2.default.PropTypes.bool,
    classParentString: _react2.default.PropTypes.string
  },

  //If no transition time or easing is passed then default to this
  getDefaultProps: function getDefaultProps() {
    return {
      transitionTime: 400,
      easing: 'linear',
      startOpen: false,
      classParentString: 'Collapsible'
    };
  },

  //Defaults the dropdown to be closed
  getInitialState: function getInitialState() {

    if (this.props.startOpen) {
      return {
        isClosed: false,
        shouldSwitchAutoOnNextCycle: false,
        height: 'auto',
        transition: 'none'
      };
    } else {
      return {
        isClosed: true,
        shouldSwitchAutoOnNextCycle: false,
        height: 0,
        transition: 'height ' + this.props.transitionTime + 'ms ' + this.props.easing
      };
    }
  },

  componentDidMount: function componentDidMount() {
    var _this = this;

    //Set up event listener to listen to transitionend so we can switch the height from fixed pixel to auto for much responsiveness;
    //TODO:  Once Synthetic transitionend events have been exposed in the next release of React move this funciton to a function handed to the onTransitionEnd prop

    this.refs.outer.addEventListener('transitionend', function (event) {
      if (_this.state.isClosed === false) {
        _this.setState({
          shouldSwitchAutoOnNextCycle: true
        });
      }
    });
  },

  componentDidUpdate: function componentDidUpdate() {
    var _this2 = this;

    if (this.state.shouldSwitchAutoOnNextCycle === true && this.state.isClosed === false) {
      //Set the height to auto to make compoenent re-render with the height set to auto.
      //This way the dropdown will be responsive and also change height if there is another dropdown within it.
      this.setState({
        height: 'auto',
        transition: 'none',
        shouldSwitchAutoOnNextCycle: false
      });
    }

    if (this.state.shouldSwitchAutoOnNextCycle === true && this.state.isClosed === true) {

      //The height has been changes back to fixed pixel, we set a small timeout to force the CSS transition back to 0 on the next tick.
      window.setTimeout(function () {
        _this2.setState({
          height: 0,
          shouldSwitchAutoOnNextCycle: false,
          transition: 'height ' + _this2.props.transitionTime + 'ms ' + _this2.props.easing
        });
      }, 50);
    }
  },

  handleTriggerClick: function handleTriggerClick(event) {

    event.preventDefault();

    if (this.state.isClosed === true) {
      this.setState({
        height: this.refs.inner.offsetHeight,
        transition: 'height ' + this.props.transitionTime + 'ms ' + this.props.easing,
        isClosed: false
      });
    } else {
      this.setState({
        isClosed: true,
        shouldSwitchAutoOnNextCycle: true,
        height: this.refs.inner.offsetHeight
      });
    }
  },

  render: function render() {

    var dropdownStyle = {
      height: this.state.height,
      transition: this.state.transition,
      overflow: 'hidden'
    };

    var openClass = this.state.isClosed ? 'is-closed' : 'is-open';

    return _react2.default.createElement(
      'div',
      { className: this.props.classParentString },
      _react2.default.createElement(
        'a',
        { href: '#', className: this.props.classParentString + "__trigger" + ' ' + openClass, onClick: this.handleTriggerClick },
        this.props.triggerText
      ),
      _react2.default.createElement(
        'div',
        { className: this.props.classParentString + "__contentOuter", ref: 'outer', style: dropdownStyle },
        _react2.default.createElement(
          'div',
          { className: this.props.classParentString + "__contentInner", ref: 'inner' },
          this.props.children
        )
      )
    );
  }

});

exports.default = Collapsible;

